/*-------------------------------------------------------------------------+
| Copyright 2018 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.compose;

import static org.conqat.lib.commons.reflect.ReflectionUtils.isInstanceOfAny;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.af3.platform.compose.PlatformArchitectureElementCompositorBase;
import org.fortiss.af3.platform.model.IPlatformArchitectureElement;
import org.fortiss.af3.platform.raspberry.model.ActuatorPWM;
import org.fortiss.af3.platform.raspberry.model.CanConnector;
import org.fortiss.af3.platform.raspberry.model.ConsoleOutput;
import org.fortiss.af3.platform.raspberry.model.RaspberryPi;
import org.fortiss.af3.platform.raspberry.model.brick.AccelerationXSensor;
import org.fortiss.af3.platform.raspberry.model.brick.AccelerationYSensor;
import org.fortiss.af3.platform.raspberry.model.brick.AccelerationZSensor;
import org.fortiss.af3.platform.raspberry.model.brick.ActuatorDigits;
import org.fortiss.af3.platform.raspberry.model.brick.AngularVelocityXSensor;
import org.fortiss.af3.platform.raspberry.model.brick.AngularVelocityYSensor;
import org.fortiss.af3.platform.raspberry.model.brick.AngularVelocityZSensor;
import org.fortiss.af3.platform.raspberry.model.brick.LEDButtonBActuator;
import org.fortiss.af3.platform.raspberry.model.brick.LEDButtonGActuator;
import org.fortiss.af3.platform.raspberry.model.brick.LEDButtonRActuator;
import org.fortiss.af3.platform.raspberry.model.brick.LaserRangeSensor;
import org.fortiss.af3.platform.raspberry.model.brick.UltraSonicSensor;
import org.fortiss.af3.platform.raspberry.model.camera.CameraDetectionStateLeft;
import org.fortiss.af3.platform.raspberry.model.camera.CameraDetectionStateRight;
import org.fortiss.af3.platform.raspberry.model.camera.CameraDistanceLeft;
import org.fortiss.af3.platform.raspberry.model.camera.CameraDistanceRight;
import org.fortiss.af3.platform.raspberry.model.camera.CameraYawAngle;
import org.fortiss.af3.platform.raspberry.model.gamepad.GamepadReceiverBase;
import org.fortiss.af3.platform.raspberry.model.motorcontrol.MotorControlInput;
import org.fortiss.af3.platform.raspberry.model.motorcontrol.MotorControlOutput;
import org.fortiss.af3.platform.raspberry.model.rumblepad.RumbleMagnitudeStrong;
import org.fortiss.af3.platform.raspberry.model.rumblepad.RumbleMagnitudeWeak;
import org.fortiss.af3.platform.raspberry.model.rumblepad.RumblepadReceiverBase;
import org.fortiss.af3.platform.raspberry.model.rumblepad.SimpleRumbleFeature;
import org.fortiss.tooling.kernel.extension.data.IElementCompositionContext;
import org.fortiss.tooling.kernel.extension.data.Prototype;

/** Compositor for the {@link RaspberryPi}. */
public class RaspberryPiCompositor extends
		PlatformArchitectureElementCompositorBase<IPlatformArchitectureElement> {
	/** {@inheritDoc} */
	@Override
	public boolean canComposePrototype(Prototype prototype) {
		return super.canComposePrototype(prototype);
	}

	/** {@inheritDoc} */
	@Override
	public boolean canCompose(IPlatformArchitectureElement container, EObject contained,
			IElementCompositionContext context) {
		return super.canCompose(container, contained, context);
	}

	/** {@inheritDoc} */
	@Override
	protected boolean isCorrectElementClass(IPlatformArchitectureElement container,
			EObject contained) {
		final boolean instanceOfAny2 =
				isInstanceOfAny(contained, CanConnector.class, ActuatorPWM.class,
						ConsoleOutput.class, GamepadReceiverBase.class, UltraSonicSensor.class,
						LaserRangeSensor.class, AccelerationXSensor.class,
						AccelerationYSensor.class, AccelerationZSensor.class,
						AngularVelocityXSensor.class, AngularVelocityYSensor.class,
						AngularVelocityZSensor.class, ActuatorDigits.class,
						LEDButtonRActuator.class, LEDButtonGActuator.class,
						LEDButtonBActuator.class, RumblepadReceiverBase.class,
						SimpleRumbleFeature.class, RumbleMagnitudeStrong.class,
						RumbleMagnitudeWeak.class, MotorControlInput.class,
						MotorControlOutput.class, CameraDistanceLeft.class,
						CameraDistanceRight.class, CameraYawAngle.class,
						CameraDetectionStateLeft.class, CameraDetectionStateRight.class);
		if(container != null) {
			final boolean instanceOfAny = isInstanceOfAny(container, RaspberryPi.class);
			return instanceOfAny && instanceOfAny2;
		}
		return instanceOfAny2;
	}
}
