/*-------------------------------------------------------------------------+
| Copyright 2018 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.generator.executable;

import static org.fortiss.af3.expression.utils.ExpressionModelElementFactory.funcCall;
import static org.fortiss.af3.expression.utils.ExpressionModelElementFactory.stringConst;

import org.fortiss.af3.component.model.OutputPort;
import org.fortiss.af3.expression.model.terms.IExpressionTerm;
import org.fortiss.af3.expression.model.terms.StringConst;
import org.fortiss.af3.expression.model.types.TDouble;
import org.fortiss.af3.platform.language.executable.ExecutableBase;
import org.fortiss.af3.platform.language.executable.IWritableExecutableWithNoValSupport;
import org.fortiss.af3.platform.raspberry.model.ConsoleOutput;
import org.fortiss.af3.project.model.typesystem.IType;

/** Executable for {@link ConsoleOutput}. */
public class ConsoleOutputExecutable extends ExecutableBase<ConsoleOutput> implements
		IWritableExecutableWithNoValSupport {
	/** Constructor. */
	public ConsoleOutputExecutable(ConsoleOutput modelElement) {
		super(modelElement);
	}

	/** {@inheritDoc} */
	@Override
	public IExpressionTerm getValueWriteAccessor(OutputPort logicalSignal, IExpressionTerm value) {
		String typeFormat = getTypeFormat(logicalSignal.getVariableType());
		StringConst format = stringConst(logicalSignal.getName() + " = " + typeFormat + "\n");
		return funcCall("printf", format, value);
	}

	/** Returns the C format string for the given type. */
	private String getTypeFormat(IType type) {
		if(type instanceof TDouble) {
			return "%f";
		}
		return "%i";
	}

	/** {@inheritDoc} */
	@Override
	public IExpressionTerm getNoValWriteAccessor(OutputPort logicalSignal) {
		StringConst format = stringConst(logicalSignal.getName() + " = NoVal");
		return funcCall("printf", format);
	}
}
