/*-------------------------------------------------------------------------+
| Copyright 2018 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.generator.executable;

import org.fortiss.af3.component.model.OutputPort;
import org.fortiss.af3.platform.raspberry.generator.executable.framework.IInitializationExecutable;
import org.fortiss.af3.platform.raspberry.generator.executable.framework.ITerminationExecutable;
import org.fortiss.af3.platform.raspberry.generator.executable.framework.IWriteableExecutable;
import org.fortiss.af3.platform.raspberry.generator.executable.library.PiHALLibraryExecutableBase;
import org.fortiss.af3.platform.raspberry.model.ActuatorPWM;

/** Executable for {@link ActuatorPWM}. */
public class PWMActuatorExecutable extends PiHALLibraryExecutableBase<ActuatorPWM> implements
		IInitializationExecutable, IWriteableExecutable, ITerminationExecutable {
	/** Constructor. */
	public PWMActuatorExecutable(ActuatorPWM modelElement) {
		super(modelElement);
	}

	/** {@inheritDoc} */
	@Override
	public String getHeaderFileName() {
		return "temp_actuator.h";
	}

	/** {@inheritDoc} */
	@Override
	public String getVariableDeclaration(String prefix) {
		return "int " + prefix + "actuator_pwm = -1;\n";
	}

	/** {@inheritDoc} */
	@Override
	public String getInitializationCode(String prefix) {
		return prefix + "actuator_pwm = temp_actuator_initialize(\"/dev/ttyACM0\");\n";
	}

	/** {@inheritDoc} */
	@Override
	public String getTerminationCode(String prefix) {
		return "temp_actuator_terminate();\n";
	}

	/** {@inheritDoc} */
	@Override
	public String getWriteCode(String prefix, OutputPort logicalSignal, String value) {
		return "temp_actuator_set_target(" + prefix + "actuator_pwm, " +
				modelElement.getChannelID() + ", " + value + ");\n";
	}

	/** {@inheritDoc} */
	@Override
	public String getNoValWriteCode(String prefix, OutputPort logicalSignal) {
		return null;
	}
}
