/*-------------------------------------------------------------------------+
| Copyright 2018 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.generator.executable.framework;

import org.fortiss.af3.platform.language.executable.ExecutableBase;

/**
 * Interface for {@link ExecutableBase}s, which require initialization including static variables in
 * the main program (e.g. a Unix file descriptor).
 * 
 * @author hoelzl
 */
public interface IInitializationExecutable {
	/**
	 * Returns the variable declarations needed by this executable. The prefix is given by the code
	 * generator to ensure uniqueness of variables for platform elements of the same type.
	 */
	String getVariableDeclaration(String prefix);

	/** Returns the initialization code. */
	String getInitializationCode(String prefix);
}
