/*-------------------------------------------------------------------------+
| Copyright 2018 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.generator.executable.framework;

/**
 * Interface implemented by platform-specific executables, which need
 * initialization during system start-up. In contrast to {@link IInitializationExecutable},
 * if there are more than one actuator or sensor with the singleton identifier, the
 * common initialization code is only included once in the generated code and it is included before
 * all other initialization code.
 * 
 * @author hoelzl
 */
public interface ISingletonInitializationExecutable {
	/** Returns the singleton identifier. */
	String getSingletonInitializationIdentifier();

	/** Returns the code to initialize local variables used by the initialization code. */
	String getSingletonVariableDeclarationCode();

	/** Returns the common initialization code. */
	String getSingletonInitializationCode();
}
