/*-------------------------------------------------------------------------+
| Copyright 2018 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.generator.executable.gamepad;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.af3.platform.raspberry.generator.executable.framework.ISingletonInitializationExecutable;
import org.fortiss.af3.platform.raspberry.generator.executable.library.PiHALLibraryExecutableBase;
import org.fortiss.af3.platform.raspberry.model.gamepad.GamepadPackage;

/**
 * Base class for all executables of the gamepad input sensors.
 * 
 * @author hoelzl
 */
abstract class GamepadExecutableBase<T extends EObject> extends PiHALLibraryExecutableBase<T>
		implements ISingletonInitializationExecutable {
	/** Constructor. */
	public GamepadExecutableBase(T modelElement) {
		super(modelElement);
	}

	/** {@inheritDoc} */
	@Override
	public final String getSingletonInitializationCode() {
		return "gamepad_configuration_t* gamepad_config = malloc(sizeof(gamepad_configuration_t));\n"
				+ "gamepad_config->device_id = \"/dev/input/js0\";\n"
				+ "gamepad_config->waiting_sleep_in_micros = 250;\n"
				+ "gamepad_config->axis_callback = NULL;\n"
				+ "gamepad_config->button_callback = NULL;"
				+ "gamepad_initialize(gamepad_config);\n\n";
	}

	/** {@inheritDoc} */
	@Override
	public final String getSingletonVariableDeclarationCode() {
		return "";
	}

	/** {@inheritDoc} */
	@Override
	public final String getSingletonInitializationIdentifier() {
		// use EMF package as singleton identifier
		return GamepadPackage.eNS_URI;
	}

	/** {@inheritDoc} */
	@Override
	public final String getHeaderFileName() {
		return "gamepad.h";
	}
}
