/*-------------------------------------------------------------------------+
| Copyright 2018 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.generator.executable.rumblepad;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.af3.component.model.InputPort;
import org.fortiss.af3.platform.raspberry.generator.executable.framework.IReadableExecutable;

/**
 * Base class for executables reading rumblepad buttons.
 * 
 * @author hoelzl
 */
abstract class ButtonExecutableBase<T extends EObject> extends RumblepadExecutableBase<T> implements
		IReadableExecutable {
	/** Constructor. */
	public ButtonExecutableBase(T modelElement) {
		super(modelElement);
	}

	/** {@inheritDoc} */
	@Override
	public final String getReadCode(String prefix, InputPort logicalSignal) {
		return "rumblepad_get_button_state(" + getButtonIdentifier() + ");\n";
	}

	/** {@inheritDoc} */
	@Override
	public final String getNoValReadCode(String prefix, InputPort logicalSignal) {
		return null;
	}

	/** Returns the button identifier as defined in {@code rumblepad.h}. */
	protected abstract String getButtonIdentifier();
}
